@@ -1123,6 +1123,10 @@ performance_profile_set_active (CcPowerPanel  *self,
   CcPowerProfile profile = cc_power_profile_from_str (profile_str);
   GtkRadioButton *button;
 
+  /* FIXME: We don't know what to do with unknown profiles */
+  if (profile == CC_POWER_PROFILE_UNKNOWN)
+    return;
+
   button = cc_power_profile_row_get_radio_button (CC_POWER_PROFILE_ROW (self->power_profiles_row[profile]));
   if (!button) {
     g_warning ("Not setting profile '%s' as it doesn't have a widget", profile_str);
@@ -1446,6 +1450,11 @@ setup_power_profiles (CcPowerPanel *self)
                name, variant_lookup_string (profile_variant, "Driver"));
 
       profile = cc_power_profile_from_str (name);
+
+      /* FIXME: We don't know what to do with unknown profiles */
+      if (profile == CC_POWER_PROFILE_UNKNOWN)
+        continue;
+
       row = cc_power_profile_row_new (cc_power_profile_from_str (name));
       g_signal_connect_object (G_OBJECT (row), "button-toggled",
                                G_CALLBACK (power_profile_button_toggled_cb), self,
