@@ -206,8 +206,6 @@ activate_panel (CcWindow          *self,
 
   timer = g_timer_new ();
 
-  g_settings_set_string (self->settings, "last-panel", id);
-
   /* Begin the profile */
   g_timer_start (timer);
 
@@ -244,6 +242,8 @@ activate_panel (CcWindow          *self,
 
   g_debug ("Time to open panel '%s': %lfs", name, ellapsed_time);
 
+  g_settings_set_string (self->settings, "last-panel", id);
+
   CC_RETURN (TRUE);
 }
 
@@ -575,6 +575,9 @@ search_entry_activate_cb (CcWindow *self)
 {
   gboolean changed;
 
+  if (cc_panel_list_get_view (self->panel_list) != CC_PANEL_LIST_SEARCH)
+    return;
+
   changed = cc_panel_list_activate (self->panel_list);
 
   gtk_search_bar_set_search_mode (self->search_bar, !changed);
@@ -663,8 +666,6 @@ window_key_press_event_cb (CcWindow    *self,
     {
       switch (event->keyval)
         {
-          case GDK_KEY_s:
-          case GDK_KEY_S:
           case GDK_KEY_f:
           case GDK_KEY_F:
             /* The search only happens when we're in the MAIN view */
